@@ -52,7 +52,26 @@ class DeformationGradient3(Matrix3):
     @classmethod
     @ensure_arguments(Pair)
     def from_pair(cls, p):
-        return cls(np.array([p.lvec, p.fvec.cross(p.lvec), p.fvec]).T)
+        """Return ``DeformationGradient3`` representing rotation defined by ``Pair``.
+
+        Rotation bring x-axis to lineation and z-axis to normal to plane
+
+        Args:
+          p (``Pair``): Pair object
+
+        Example:
+          >>> p = pair(40, 20, 75, 16)
+          >>> F = defgrad.from_pair(p)
+        """
+        return cls(
+            np.asarray(
+                [
+                    np.asarray(p.lvec),
+                    np.asarray(p.fvec.cross(p.lvec)),
+                    np.asarray(p.fvec),
+                ]
+            ).T
+        )
 
     @classmethod
     @ensure_arguments(Vector3)
@@ -67,7 +86,7 @@ class DeformationGradient3(Matrix3):
           >>> F = defgrad.from_axisangle(lin(120, 30), 45)
         """
 
-        x, y, z = vector.uv()
+        x, y, z = vector.uv()._coords
         c, s = cosd(theta), sind(theta)
         xs, ys, zs = x * s, y * s, z * s
         xc, yc, zc = x * (1 - c), y * (1 - c), z * (1 - c)
@@ -189,7 +208,7 @@ class DeformationGradient3(Matrix3):
         return type(self)(V)
 
     def axisangle(self):
-        """Return rotation part of ``DeformationGradient3`` axis, angle tuple."""
+        """Return rotation part of ``DeformationGradient3`` as axis, angle tuple."""
         R = self.R
         w, W = np.linalg.eig(R.T)
         i = np.where(abs(np.real(w) - 1.0) < 1e-8)[0]
@@ -198,17 +217,37 @@ class DeformationGradient3(Matrix3):
         axis = Vector3(np.real(W[:, i[-1]]).squeeze())
         # rotation angle depending on direction
         cosa = (np.trace(R) - 1.0) / 2.0
-        if abs(axis[2]) > 1e-8:
-            sina = (R[1][0] + (cosa - 1.0) * axis[0] * axis[1]) / axis[2]
-        elif abs(axis[1]) > 1e-8:
-            sina = (R[0][2] + (cosa - 1.0) * axis[0] * axis[2]) / axis[1]
+        if abs(axis.z) > 1e-8:
+            sina = (R[1][0] + (cosa - 1.0) * axis.x * axis.y) / axis.z
+        elif abs(axis.y) > 1e-8:
+            sina = (R[0][2] + (cosa - 1.0) * axis.x * axis.z) / axis.y
         else:
-            sina = (R[2][1] + (cosa - 1.0) * axis[1] * axis[2]) / axis[0]
+            sina = (R[2][1] + (cosa - 1.0) * axis.y * axis.z) / axis.x
         angle = np.rad2deg(np.arctan2(sina, cosa))
         return axis, angle
 
     def velgrad(self, time=1):
-        """Return ``VelocityGradient3`` for given time"""
+        """
+        Return ``VelocityGradient3`` calculated as matrix logarithm divided by given time.
+
+        Keyword Args:
+            time (float): total time. Default 1
+
+        Example:
+            >>> F = defgrad.from_comp(xx=2, xy=1, zz=0.5)
+            >>> L = F.velgrad(time=10)
+            >>> L
+            VelocityGradient3
+            [[ 0.069  0.069  0.   ]
+             [ 0.     0.     0.   ]
+             [ 0.     0.    -0.069]]
+            >>> L.defgrad(time=10)
+            DeformationGradient3
+            [[2.  1.  0. ]
+             [0.  1.  0. ]
+             [0.  0.  0.5]]
+
+        """
         from scipy.linalg import logm
 
         return VelocityGradient3(logm(np.asarray(self)) / time)
@@ -223,7 +262,7 @@ class VelocityGradient3(Matrix3):
           3x3 2D array. This includes lists, tuples and ndarrays.
 
     Returns:
-      ``VelocityGradient3`` object
+      ``VelocityGradient3`` matrix
 
     Example:
       >>> L = velgrad(np.diag([0.1, 0, -0.1]))
@@ -294,6 +333,9 @@ class Stress3(Tensor3):
     """
     The class to represent 3D stress tensor.
 
+    Note: Tensile normal stresses have positive values,
+    and compressive normal stresses have negative values.
+
     Args:
       a (3x3 array_like): Input data, that can be converted to
           3x3 2D array. This includes lists, tuples and ndarrays.
@@ -351,6 +393,81 @@ class Stress3(Tensor3):
 
         return type(self)(self - self.hydrostatic)
 
+    @property
+    def sigma1(self):
+        """
+        A maximum principal stress (max compressive)
+        """
+
+        return self.E3
+
+    @property
+    def sigma2(self):
+        """
+        A intermediate principal stress
+        """
+
+        return self.E2
+
+    @property
+    def sigma3(self):
+        """
+        A minimum principal stress (max tensile)
+        """
+
+        return self.E1
+
+    @property
+    def sigma1dir(self):
+        """
+        Return unit length vector in direction of maximum
+        principal stress (max compressive)
+        """
+
+        return self.V3
+
+    @property
+    def sigma2dir(self):
+        """
+        Return unit length vector in direction of intermediate
+        principal stress
+        """
+
+        return self.V2
+
+    @property
+    def sigma3dir(self):
+        """
+        Return unit length vector in direction of minimum
+        principal stress (max tensile)
+        """
+
+        return self.V1
+
+    @property
+    def sigma1vec(self):
+        """
+        Return maximum principal stress vector (max compressive)
+        """
+
+        return self.E3 * self.V3
+
+    @property
+    def sigma2vec(self):
+        """
+        Return intermediate principal stress vector
+        """
+
+        return self.E2 * self.V2
+
+    @property
+    def sigma3vec(self):
+        """
+        Return minimum principal stress vector (max tensile)
+        """
+
+        return self.E1 * self.V1
+
     @property
     def I1(self):
         """
@@ -417,7 +534,8 @@ class Stress3(Tensor3):
 
         """
 
-        return Fault(*self.stress_comp(n))
+        sn, tau = self.stress_comp(n)
+        return Fault(sn.normalized(), tau.normalized())
 
     def stress_comp(self, n):
         """
@@ -445,6 +563,13 @@ class Stress3(Tensor3):
         sn, tau = self.stress_comp(n)
         return abs(tau)
 
+    @property
+    def shape_ratio(self):
+        """
+        Return shape ratio R (Gephart & Forsyth 1984)
+        """
+        return float((self.sigma1 - self.sigma2) / (self.sigma1 - self.sigma3))
+
 
 class Ellipsoid(Tensor3):
     """
@@ -577,22 +702,37 @@ class Ellipsoid(Tensor3):
 
     @property
     def Rxy(self) -> float:
+        """
+        Return the Rxy ratio.
+        """
         return self.lambda1 / self.lambda2 if self.lambda2 != 0 else np.inf
 
     @property
     def Ryz(self) -> float:
+        """
+        Return the Ryz ratio.
+        """
         return self.lambda2 / self.lambda3 if self.lambda3 != 0 else np.inf
 
     @property
     def e12(self) -> float:
+        """
+        Return the e1 - e2.
+        """
         return self.e1 - self.e2
 
     @property
     def e13(self) -> float:
+        """
+        Return the e1 - e3.
+        """
         return self.e1 - self.e3
 
     @property
     def e23(self) -> float:
+        """
+        Return the e2 - e3.
+        """
         return self.e2 - self.e3
 
     @property
@@ -619,7 +759,7 @@ class Ellipsoid(Tensor3):
     @property
     def D(self) -> float:
         """
-        return the strain intensity.
+        Return the strain intensity.
         """
         return self.e12**2 + self.e23**2
 
@@ -724,18 +864,26 @@ class Ellipsoid(Tensor3):
 
     @property
     def MAD_l(self) -> float:
-        """Return maximum angular deviation (MAD) of linearly distributed vectors. Kirschvink 1980"""
+        """
+        Return maximum angular deviation (MAD) of linearly distributed vectors.
+
+        Kirschvink 1980
+        """
         return atand(np.sqrt((self.E2 + self.E3) / self.E1))
 
     @property
     def MAD_p(self) -> float:
-        """Return maximum angular deviation (MAD) of planarly distributed vectors. Kirschvink 1980"""
+        """
+        Return maximum angular deviation (MAD) of planarly distributed vectors.
+
+        Kirschvink 1980
+        """
         return atand(np.sqrt(self.E3 / self.E2 + self.E3 / self.E1))
 
     @property
     def MAD(self) -> float:
         """
-        Return approximate deviation according to shape
+        Return maximum angular deviation (MAD)
         """
 
         if self.shape > 1:
@@ -797,7 +945,7 @@ class OrientationTensor3(Ellipsoid):
     @classmethod
     def from_pairs(cls, p) -> "OrientationTensor3":
         """
-        Return Lisle (19890``Ortensor`` of orthogonal data in ``PairSet``
+        Return Lisle (1989) ``Ortensor`` of orthogonal data in ``PairSet``
 
         Lisle, R. (1989). The Statistical Analysis of Orthogonal Orientation Data. The Journal of Geology, 97(3), 360-364.
 
