@@ -1,14 +1,11 @@
 # -*- coding: utf-8 -*-
 
-# import warnings
 import pickle
 
 import numpy as np
 import matplotlib.pyplot as plt
 from matplotlib.patches import Circle
 
-# from matplotlib import MatplotlibDeprecationWarning
-
 from apsg.config import apsg_conf
 from apsg.math._vector import Vector3
 from apsg.feature._geodata import Lineation, Foliation, Pair, Fault, Cone
@@ -29,45 +26,55 @@ from apsg.plotting._plot_artists import StereoNetArtistFactory
 __all__ = ["StereoNet"]
 
 
-# Ignore `matplotlib`s deprecation warnings.
-# warnings.filterwarnings("ignore", category=MatplotlibDeprecationWarning)
-
-
 class StereoNet:
     """
     Plot features on stereographic projection
 
-    Args:
-        hemisphere: which hemisphere Default 'lower'
-        rotate_data: whether data should be rotated with overlay Default False
-        grid_position: orientation of overlay given as ``Pair`` Default pair(0, 0, 0, 0)
-        clip_pole: Default 20)
-        gridstep: grid step Default 15
-        resolution: number of grid lines points Default 361
-        n: number of contouring grid points Default 2000
-        grid_type: type of contouring grid 'gss' or 'sfs'. Default 'gss'
+    Keyword Args:
+        title (str): figure title. Default None.
+        tight_layout (bool): Matplotlib figure tight_layout. Default False
+        kind (str): Equal area ("equal-area", "schmidt" or "earea") or equal angle ("equal-angle",
+          "wulff" or "eangle") projection. Default is "equal-area"
+        hemisphere (str): "lower" or "upper". Default is "lower"
+        overlay_position (tuple or Pair): Position of overlay X, Y, Z given by Pair. X is direction
+          of linear element, Z is normal to planar. Default is (0, 0, 0, 0)
+        rotate_data (bool): Whether plotted data should be rotated together with overlay.
+          Default False
+        minor_ticks (None or float): Default None
+        major_ticks (None or float): Default None
+        overlay (bool): Whether to show overlay. Default is True
+        overlay_step (float): Grid step of overlay. Default 15
+        overlay_resolution (float): Resolution of overlay. Default 181
+        clip_pole (float): Clipped cone around poles. Default 15
+        grid_type (str): Type of contouring grid "gss" or "sfs". Default "gss"
+        grid_n (int): Number of counting points in grid. Default 3000
+
+    Examples:
+        >>> l = linset.random_fisher(position=lin(120, 40))
+        >>> s = StereoNet(title="Random linear features")
+        >>> s.contour(l)
+        >>> s.line(l)
+        >>> s.show()
     """
 
     def __init__(self, **kwargs):
         self._kwargs = apsg_conf["stereonet_default_kwargs"].copy()
         self._kwargs.update((k, kwargs[k]) for k in self._kwargs.keys() & kwargs.keys())
         self._kwargs["title"] = kwargs.get("title", None)
-        if self._kwargs["kind"].lower() in ["equal-area", "schmidt", "earea"]:
-            self.proj = EqualAreaProj(**self._kwargs)
-        elif self._kwargs["kind"].lower() in ["equal-angle", "wulff", "eangle"]:
-            self.proj = EqualAngleProj(**self._kwargs)
-        else:
-            raise TypeError("Only 'Equal-area' and 'Equal-angle' implemented")
+        self.grid = StereoGrid(**self._kwargs)
+        # alias for Projection instance
+        self.proj = self.grid.proj
         self.angles_gc = np.linspace(
             -90 + 1e-7, 90 - 1e-7, int(self.proj.overlay_resolution / 2)
         )
         self.angles_sc = np.linspace(
             -180 + 1e-7, 180 - 1e-7, self.proj.overlay_resolution
         )
-        self.grid = StereoGrid(**self._kwargs)
+
         self.clear()
 
     def clear(self):
+        """Clear plot"""
         self._artists = []
 
     def _draw_layout(self):
@@ -139,11 +146,13 @@ class StereoNet:
             plot_method(*artist.args, **artist.kwargs)
 
     def to_json(self):
+        """Return stereonet as JSON dict"""
         artists = [artist.to_json() for artist in self._artists]
         return dict(kwargs=self._kwargs, artists=artists)
 
     @classmethod
     def from_json(cls, json_dict):
+        """Create stereonet from JSON dict"""
         s = cls(**json_dict["kwargs"])
         s._artists = [
             stereonetartist_from_json(artist) for artist in json_dict["artists"]
@@ -151,11 +160,23 @@ class StereoNet:
         return s
 
     def save(self, filename):
+        """
+        Save stereonet to pickle file
+
+        Args:
+            filename (str): name of picke file
+        """
         with open(filename, "wb") as f:
             pickle.dump(self.to_json(), f, pickle.HIGHEST_PROTOCOL)
 
     @classmethod
     def load(cls, filename):
+        """
+        Load stereonet from pickle file
+
+        Args:
+            filename (str): name of picke file
+        """
         with open(filename, "rb") as f:
             data = pickle.load(f)
         return cls.from_json(data)
@@ -195,21 +216,35 @@ class StereoNet:
         if self._kwargs["tight_layout"]:
             self.fig.tight_layout()
 
-    def render(self):
-        if not hasattr(self, "fig"):
-            self.init_figure()
-        else:
-            self.fig.clear()
+    def render2fig(self, fig):
+        """
+        Plot stereonet to already existing figure or subfigure
+
+        Args:
+            fig (Figure): A mtplotlib Figure artist
+        """
+        self.fig = fig
         self._render()
 
     def show(self):
+        """Show stereonet"""
         plt.close(0)  # close previously rendered figure
         self.init_figure()
         self._render()
         plt.show()
 
     def savefig(self, filename="stereonet.png", **kwargs):
-        self.render()
+        """
+        Save stereonet figure to graphics file
+
+        Keyword Args:
+            filename (str): filename
+
+        All others kwargs are passed to matplotlib `Figure.savefig`
+        """
+        plt.close(0)  # close previously rendered figure
+        self.init_figure()
+        self._render()
         self.fig.savefig(filename, **kwargs)
         plt.close(0)
 
@@ -308,13 +343,33 @@ class StereoNet:
             print(err)
 
     def contour(self, *args, **kwargs):
-        """Plot filled contours."""
+        """
+        Plot filled contours using modified Kamb contouring technique with exponential smoothing
+
+        Keyword Args:
+            levels (int or list): number or values of contours. Default 6
+            cmap: matplotlib colormap used for filled contours. Default "Greys"
+            colorbar (bool): Show colorbar. Default False
+            alpha (float): transparency. Default None
+            antialiased (bool): Default True
+            sigma (float): If None it is automatically calculated
+            sigmanorm (bool): If True scaled counts are normalized by sigma. Default True
+            trimzero (bool): Remove values equal to 0. Default True
+            clines (bool): Show contour lines instead filled contours. Default False
+            linewidths (float): contour lines width
+            linestyles (str): contour lines style
+            show_data (bool): Show data as points. Default False
+            data_kwargs (dict): arguments passed to point factory
+        """
         try:
             artist = StereoNetArtistFactory.create_contour(*args, **kwargs)
             # ad-hoc density calculation needed to access correct grid properties
             if len(args) > 0:
                 self.grid.calculate_density(
-                    args[0], sigma=kwargs.get("sigma"), trim=kwargs.get("trim")
+                    args[0],
+                    sigma=artist.kwargs.get("sigma"),
+                    sigmanorm=artist.kwargs.get("sigmanorm"),
+                    trimzero=artist.kwargs.get("trimzero"),
                 )
             self._artists.append(artist)
         except TypeError as err:
@@ -369,7 +424,10 @@ class StereoNet:
                 # plot on lower
                 x, y = self.proj.project_data(
                     *np.array(
-                        [Vector3(dv).rotate(Vector3(fol), a) for a in self.angles_gc]
+                        [
+                            np.asarray(Vector3(dv).rotate(Vector3(fol), a))
+                            for a in self.angles_gc
+                        ]
                     ).T
                 )
                 X.append(np.hstack((x, np.nan)))
@@ -377,7 +435,10 @@ class StereoNet:
                 # plot on upper
                 x, y = self.proj.project_data(
                     *np.array(
-                        [-Vector3(dv).rotate(Vector3(fol), a) for a in self.angles_gc]
+                        [
+                            -np.asarray(Vector3(dv).rotate(Vector3(fol), a))
+                            for a in self.angles_gc
+                        ]
                     ).T
                 )
                 X.append(np.hstack((x, np.nan)))
@@ -398,7 +459,9 @@ class StereoNet:
             steps = max(2, int(arg1.angle(arg2)))
             # plot on lower
             x_lower, y_lower, x_upper, y_upper = self.proj.project_data_antipodal(
-                *np.array([arg1.slerp(arg2, t) for t in np.linspace(0, 1, steps)]).T
+                *np.array(
+                    [np.asarray(arg1.slerp(arg2, t)) for t in np.linspace(0, 1, steps)]
+                ).T
             )
             X_lower.append(np.hstack((x_lower, np.nan)))
             Y_lower.append(np.hstack((y_lower, np.nan)))
@@ -488,13 +551,17 @@ class StereoNet:
                 # plot on lower
                 angles = np.linspace(0, c.revangle, max(2, abs(int(c.revangle))))
                 x, y = self.proj.project_data(
-                    *np.array([c.secant.rotate(c.axis, a) for a in angles]).T
+                    *np.array(
+                        [np.asarray(c.secant.rotate(c.axis, a)) for a in angles]
+                    ).T
                 )
                 X.append(np.hstack((x, np.nan)))
                 Y.append(np.hstack((y, np.nan)))
                 # plot on upper
                 x, y = self.proj.project_data(
-                    *np.array([-c.secant.rotate(c.axis, a) for a in angles]).T
+                    *np.array(
+                        [-np.asarray(c.secant.rotate(c.axis, a)) for a in angles]
+                    ).T
                 )
                 X.append(np.hstack((x, np.nan)))
                 Y.append(np.hstack((y, np.nan)))
@@ -531,36 +598,44 @@ class StereoNet:
             self._arrow(arg.fol, arg.lin, sense=arg.sense, **quiver_kwargs)
 
     def _arrow(self, *args, **kwargs):
-        x_lower, y_lower = self.proj.project_data(*np.vstack(np.atleast_2d(args[0])).T)
+        sense = kwargs.pop("sense") * np.ones(
+            np.atleast_2d(np.asarray(args[0])).shape[0]
+        )
+        x_lower, y_lower = self.proj.project_data(
+            *np.vstack(np.atleast_2d(np.asarray(args[0]))).T
+        )
         x_upper, y_upper = self.proj.project_data(
-            *(-np.vstack(np.atleast_2d(args[0])).T)
+            *(-np.vstack(np.atleast_2d(np.asarray(args[0]))).T)
         )
         x = np.hstack((x_lower, x_upper))
-        x = x[~np.isnan(x)]
         y = np.hstack((y_lower, y_upper))
-        y = y[~np.isnan(y)]
+        sense = np.hstack((sense, sense))
+        inside = ~np.isnan(x)
+        x = x[inside]
+        y = y[inside]
+        sense = sense[inside]
         if len(args) > 1:
             x_lower, y_lower = self.proj.project_data(
-                *np.vstack(np.atleast_2d(args[1])).T
+                *np.vstack(np.atleast_2d(np.asarray(args[1]))).T
             )
             x_upper, y_upper = self.proj.project_data(
-                *(-np.vstack(np.atleast_2d(args[1])).T)
+                *(-np.vstack(np.atleast_2d(np.asarray(args[1]))).T)
             )
             dx = np.hstack((x_lower, x_upper))
-            dx = dx[~np.isnan(dx)]
             dy = np.hstack((y_lower, y_upper))
+            dx = dx[~np.isnan(dx)]
             dy = dy[~np.isnan(dy)]
         else:
             dx, dy = x, y
         mag = np.hypot(dx, dy)
-        sense = np.atleast_1d(kwargs.pop("sense"))
         u, v = sense * dx / mag, sense * dy / mag
         h = self.ax.quiver(x, y, u, v, **kwargs)
         h.set_clip_path(self.primitive)
 
     def _contour(self, *args, **kwargs):
         sigma = kwargs.pop("sigma")
-        trim = kwargs.pop("trim")
+        trimzero = kwargs.pop("trimzero")
+        sigmanorm = (kwargs.pop("sigmanorm"),)
         colorbar = kwargs.pop("colorbar")
         _ = kwargs.pop("label")
         clines = kwargs.pop("clines")
@@ -570,7 +645,9 @@ class StereoNet:
         data_kwargs = kwargs.pop("data_kwargs")
         if not self.grid.calculated:
             if len(args) > 0:
-                self.grid.calculate_density(args[0], sigma=sigma, trim=trim)
+                self.grid.calculate_density(
+                    args[0], sigma=sigma, sigmanorm=sigmanorm, trimzero=trimzero
+                )
             else:
                 return None
         dcgrid = np.asarray(self.grid.grid).T
